@@ -1,6 +1,7 @@
 """Github service module."""
 from __future__ import annotations
 
+import abc
 import copy
 from typing import Any
 
@@ -19,7 +20,28 @@ class GithubServiceError(Exception):
     pass
 
 
-class GithubService:
+class AbstractGithubService(abc.ABC):
+    """Abstract Github service class."""
+
+    @abc.abstractmethod
+    def list_issues_from_repo(
+        self,
+        github_repo: str,
+        request: il.IssueListValidRequest | il.IssueListInvalidRequest,
+    ) -> list[i.Issue]:
+        """Return list of issues from one repository."""
+        raise NotImplementedError  # pragma: no cover
+
+    @staticmethod
+    @abc.abstractmethod
+    def link_issues(
+        pr_base: pr.PullRequest, filtered_issues: list[i.Issue]
+    ) -> pr.PullRequest:
+        """Return a new PR with body message and labels of linked issues."""
+        raise NotImplementedError  # pragma: no cover
+
+
+class GithubService(AbstractGithubService):
     """Github service class."""
 
     def __init__(self, github_config: cs.GhConnectionSettings) -> None:
@@ -52,9 +74,14 @@ class GithubService:
         try:
             return connection.me()
         except github3.exceptions.AuthenticationFailed:
-            raise GithubServiceError("Invalid token.") from None
+            raise GithubServiceError(
+                "Wrong GitHub permissions. Please check your token."
+            ) from None
         except github3.exceptions.ConnectionError as github_error:
-            raise ConnectionError() from github_error
+            raise GithubServiceError(
+                "Unable to reach server. Please check your network and credentials. "
+                "This also happens when Github is offline, then try again later."
+            ) from github_error
         except github3.exceptions.IncompleteResponse:
             raise GithubServiceError(
                 "Invalid response. Your token might not be properly scoped."
@@ -255,7 +282,7 @@ class GithubService:
         head = f"{pr_merge.prefix}:{pr_merge.head}"
         pulls = list(repo.pull_requests(base=pr_merge.base, head=head))
         if not pulls:
-            return (
+            raise GithubServiceError(
                 f"{github_repo}: no open PR found for "
                 f"{pr_merge.base}:{pr_merge.head}.\n"
             )
