@@ -12,13 +12,9 @@ import git_portfolio.use_cases.command_checker as command_checker
 class PoetryUseCase:
     """Execution of poetry use case."""
 
-    def __init__(self) -> None:
-        """Constructor."""
-        self.err_output = command_checker.CommandChecker().check("poetry")
-
     def execute(
         self, git_selected_repos: list[str], command: str, args: tuple[str]
-    ) -> res.ResponseFailure | res.ResponseSuccess:
+    ) -> list[res.Response]:
         """Batch `poetry` command.
 
         Args:
@@ -27,15 +23,16 @@ class PoetryUseCase:
             args: command arguments.
 
         Returns:
-            Union[res.ResponseFailure, res.ResponseSuccess]: final result.
+            list[res.Response]: final results.
         """
-        if self.err_output:
-            return res.ResponseFailure(res.ResponseTypes.SYSTEM_ERROR, self.err_output)
-        output = ""
+        err_output = command_checker.CommandChecker().check("poetry")
+        if err_output:
+            return [res.ResponseFailure(res.ResponseTypes.SYSTEM_ERROR, err_output)]
+        responses: list[res.Response] = []
         cwd = pathlib.Path().absolute()
         for repo_name in git_selected_repos:
             folder_name = repo_name.split("/")[1]
-            output += f"{folder_name}: "
+            output = f"{folder_name}: "
             try:
                 popen = subprocess.Popen(  # noqa: S603, S607
                     [command, *args],
@@ -51,9 +48,16 @@ class PoetryUseCase:
                     else:
                         stdout_str = stdout.decode("utf-8")
                         output += f"{stdout_str}\n"
+                    responses.append(res.ResponseSuccess(output))
                 else:
                     error_str = error.decode("utf-8")
                     output += f"{error_str}"
+                    responses.append(
+                        res.ResponseFailure(res.ResponseTypes.RESOURCE_ERROR, output)
+                    )
             except FileNotFoundError as fnf_error:
                 output += f"{fnf_error.strerror}: {fnf_error.filename}\n"
-        return res.ResponseSuccess(output)
+                responses.append(
+                    res.ResponseFailure(res.ResponseTypes.RESOURCE_ERROR, output)
+                )
+        return responses
