@@ -1,16 +1,16 @@
 """List issue on Github use case."""
-from typing import Union
+from __future__ import annotations
 
-import git_portfolio.github_service as ghs
+import git_portfolio.github_service as gs
 import git_portfolio.request_objects.issue_list as il
 import git_portfolio.responses as res
 
 
 def issues(
     github_repo: str,
-    github_service: ghs.GithubService,
-    request: Union[il.IssueListValidRequest, il.IssueListInvalidRequest],
-) -> Union[res.ResponseSuccess, res.ResponseFailure]:
+    github_service: gs.AbstractGithubService,
+    request: il.IssueListValidRequest | il.IssueListInvalidRequest,
+) -> res.Response:
     """Return a list of matching issues."""
     if isinstance(request, il.IssueListInvalidRequest):
         return res.build_response_from_invalid_request(request)
